@@ -32,6 +32,9 @@ class CreateWeappQRUrlRequest(AbstractModel):
 
     @property
     def SessionKey(self):
+        """代理角色临时密钥的Token
+        :rtype: str
+        """
         return self._SessionKey
 
     @SessionKey.setter
@@ -60,7 +63,7 @@ class CreateWeappQRUrlResponse(AbstractModel):
         r"""
         :param _Url: 渠道备案小程序二维码
         :type Url: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Url = None
@@ -68,6 +71,9 @@ class CreateWeappQRUrlResponse(AbstractModel):
 
     @property
     def Url(self):
+        """渠道备案小程序二维码
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -76,6 +82,9 @@ class CreateWeappQRUrlResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -112,7 +121,7 @@ class DescribeGetAuthInfoResponse(AbstractModel):
 
 其余为普通的用户
         :type Level: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._IsTenPayMasked = None
@@ -123,6 +132,9 @@ class DescribeGetAuthInfoResponse(AbstractModel):
 
     @property
     def IsTenPayMasked(self):
+        """实名认证状态：0未实名，1已实名
+        :rtype: str
+        """
         return self._IsTenPayMasked
 
     @IsTenPayMasked.setter
@@ -131,6 +143,9 @@ class DescribeGetAuthInfoResponse(AbstractModel):
 
     @property
     def IsAuthenticated(self):
+        """实名认证类型：0个人，1企业
+        :rtype: str
+        """
         return self._IsAuthenticated
 
     @IsAuthenticated.setter
@@ -139,6 +154,9 @@ class DescribeGetAuthInfoResponse(AbstractModel):
 
     @property
     def Type(self):
+        """认证类型，个人0，企业1
+        :rtype: str
+        """
         return self._Type
 
     @Type.setter
@@ -147,6 +165,12 @@ class DescribeGetAuthInfoResponse(AbstractModel):
 
     @property
     def Level(self):
+        """大客户标识：
+1004、1003、1002、1001
+
+其余为普通的用户
+        :rtype: str
+        """
         return self._Level
 
     @Level.setter
@@ -155,6 +179,9 @@ class DescribeGetAuthInfoResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -196,6 +223,9 @@ class SyncIcpOrderWebInfoRequest(AbstractModel):
 
     @property
     def IcpOrderId(self):
+        """备案ICP订单号
+        :rtype: str
+        """
         return self._IcpOrderId
 
     @IcpOrderId.setter
@@ -204,6 +234,9 @@ class SyncIcpOrderWebInfoRequest(AbstractModel):
 
     @property
     def SourceWebId(self):
+        """订单里的webId
+        :rtype: str
+        """
         return self._SourceWebId
 
     @SourceWebId.setter
@@ -212,6 +245,9 @@ class SyncIcpOrderWebInfoRequest(AbstractModel):
 
     @property
     def TargetWebIds(self):
+        """订单里的webId 数组(如果传入的webIds含有 订单中不包含的webId，会自动跳过)
+        :rtype: list of str
+        """
         return self._TargetWebIds
 
     @TargetWebIds.setter
@@ -220,6 +256,9 @@ class SyncIcpOrderWebInfoRequest(AbstractModel):
 
     @property
     def SyncFields(self):
+        """网站信息字段名 数组
+        :rtype: list of str
+        """
         return self._SyncFields
 
     @SyncFields.setter
@@ -228,6 +267,9 @@ class SyncIcpOrderWebInfoRequest(AbstractModel):
 
     @property
     def CheckSamePerson(self):
+        """是否先判断同步的网站负责人是否一致 (这里会判断 sitePersonName, sitePersonCerType,sitePersonCerNum三个字段完全一致)  默认:true. 非必要 不建议关闭修改该参数默认值
+        :rtype: bool
+        """
         return self._CheckSamePerson
 
     @CheckSamePerson.setter
@@ -258,13 +300,16 @@ class SyncIcpOrderWebInfoResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
